@@ -2,13 +2,14 @@ package Text::Markdown;
 require 5.008_000;
 use strict;
 use warnings;
+use re 'eval';
 
 use Digest::MD5 qw(md5_hex);
 use Encode      qw();
 use Carp        qw(croak);
 use base        'Exporter';
 
-our $VERSION   = '1.0.20';
+our $VERSION   = '1.0.23';
 our @EXPORT_OK = qw(markdown);
 
 =head1 NAME
@@ -57,7 +58,7 @@ This module implements the 'original' Markdown markdown syntax from:
 
 =head1 OPTIONS
 
-Text::Markdown supports a number of options to it's processor which control the behavior of the output document.
+Text::Markdown supports a number of options to it's processor which control the behaviour of the output document.
 
 These options can be supplied to the constructor, on in a hash with the individual calls to the markdown method.
 See the synopsis for examples of both of the above styles.
@@ -475,9 +476,10 @@ sub _RunBlockGamut {
     $text = $self->_HashHTMLBlocks($text) unless $self->{markdown_in_html_blocks};
 
     # Do Horizontal Rules:
-    $text =~ s{^[ ]{0,2}([ ]?\*[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
-    $text =~ s{^[ ]{0,2}([ ]? -[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
-    $text =~ s{^[ ]{0,2}([ ]? _[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
+    my $less_than_tab = $self->{tab_width} - 1;
+    $text =~ s{^[ ]{0,$less_than_tab}(\*[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
+    $text =~ s{^[ ]{0,$less_than_tab}(-[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
+    $text =~ s{^[ ]{0,$less_than_tab}(_[ ]?){3,}[ \t]*$}{\n<hr$self->{empty_element_suffix}\n}gmx;
 
     $text = $self->_DoLists($text);
 
@@ -1375,7 +1377,7 @@ sub _DoAutoLinks {
         <
         (?:mailto:)?
         (
-            [-.\w]+
+            [-.\w\+]+
             \@
             [-a-z0-9]+(\.[-a-z0-9]+)*\.[a-z]+
         )
@@ -1606,7 +1608,7 @@ and it *is not* in any way blessed by him.
 
 Whilst this code aims to be compatible with the original Markdown.pl (and incorporates 
 and passes the Markdown test suite) whilst fixing a number of bugs in the original - 
-there may be differences between the behavior of this module and Markdown.pl. If you find
+there may be differences between the behaviour of this module and Markdown.pl. If you find
 any differences where you believe Text::Markdown behaves contrary to the Markdown spec, 
 please report them as bugs.
 
